@@ -3,7 +3,9 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "OCREngine.h"
+#include <QFileInfo>
 #include <DOcr>
+#include "util/log.h"
 
 OCREngine *OCREngine::instance()
 {
@@ -22,10 +24,16 @@ OCREngine::OCREngine()
     //初始化插件管理库
     //此处存在产品设计缺陷: 无法选择插件，无鉴权入口，无性能方面的高级设置入口
     //因此此处直接硬编码使用默认插件
+    qCInfo(dmOcr) << "Initializing OCR driver";
     ocrDriver = new Dtk::Ocr::DOcr;
     ocrDriver->loadDefaultPlugin();
     ocrDriver->setUseMaxThreadsCount(2);
-    ocrDriver->setUseHardware({{Dtk::Ocr::HardwareID::GPU_Vulkan, 0}});
+    QFileInfo mtfi("/dev/mtgpu.0");
+    if (mtfi.exists()) {
+        qCInfo(dmOcr) << "GPU device found, enabling Vulkan hardware acceleration";
+        ocrDriver->setUseHardware({{Dtk::Ocr::HardwareID::GPU_Vulkan, 0}});
+    }
+    qCInfo(dmOcr) << "OCR driver initialization completed";
 }
 
 void OCREngine::setImage(const QImage &image)
@@ -36,19 +44,28 @@ void OCREngine::setImage(const QImage &image)
 
 QString OCREngine::getRecogitionResult()
 {
+    qCInfo(dmOcr) << "Starting OCR recognition";
     m_isRunning = true;
 
     ocrDriver->analyze();
 
     m_isRunning = false;
-    return ocrDriver->simpleResult();
+    QString result = ocrDriver->simpleResult();
+    qCInfo(dmOcr) << "OCR recognition completed";
+    return result;
 }
 
 bool OCREngine::setLanguage(const QString &language)
 {
+    qCInfo(dmOcr) << "Setting OCR language to:" << language;
     if(ocrDriver->isRunning()) {
+        qCInfo(dmOcr) << "Breaking current analysis for language change";
         ocrDriver->breakAnalyze();
     }
 
-    return ocrDriver->setLanguage(language);
+    bool success = ocrDriver->setLanguage(language);
+    if (!success) {
+        qCWarning(dmOcr) << "Failed to set language:" << language;
+    }
+    return success;
 }
